package locales

// AUTOGENERATED FILE: DO NOT MODIFY BY HAND.
// Instead, modify the .po files in
// https://github.com/hebcal/hebcal-locales.git
// and run
//
//	npm run po2golang
//
// there. Then copy the contents of the go/ folder.

var dict_ashkenazi_standard = map[string]string{
	"Achrei Mot":                "Acharei",
	"Alot haShachar":            "Alos HaShachar",
	"Alot HaShachar":            "Alos HaShachar",
	"Asara B'Tevet":             "Asarah BeTeives",
	"Asara B'Tevet (Mincha)":    "Asarah BeTeives (Minchah)",
	"Avot":                      "Avos",
	"Baba Batra":                "Bava Basra",
	"Baba Kamma":                "Bava Kamma",
	"Baba Metzia":               "Bava Metzia",
	"Bamidbar":                  "Bemidbar",
	"Bechorot":                  "Bechoros",
	"Bechukotai":                "Bechukosai",
	"Beha'alotcha":              "Beha'aloscha",
	"Bein HaShemashot":          "Bein HaShemashos",
	"Bekhorot":                  "Bechoros",
	"Berachot":                  "Berachos",
	"Bereshit":                  "Bereishis",
	"Chatzot hayom":             "Chatzos HaYom",
	"Chatzot HaYom":             "Chatzos HaYom",
	"Chayei Sara":               "Chayei Sarah",
	"Chukat":                    "Chukas",
	"Erev Rosh Hashana":         "Erev Rosh Hashanah",
	"Erev Shavuot":              "Erev Shavuos",
	"Erev Simchat Torah":        "Erev Simchas Torah",
	"Erev Sukkot":               "Erev Sukkos",
	"Erev Tish'a B'Av":          "Erev Tishah BeAv",
	"Eruvin":                    "Eiruvin",
	"Horayot":                   "Horayos",
	"Keritot":                   "Kerisos",
	"Ketubot":                   "Kesubos",
	"Ki Tavo":                   "Ki Savo",
	"Ki Teitzei":                "Ki Seitzei",
	"Ki Tisa":                   "Ki Sisa",
	"Kriat Shema, sof zeman":    "Sof Zman Krias Shma",
	"Lech-Lecha":                "Lech Lecha",
	"Leil Selichot":             "Slichos",
	"Makkot":                    "Makkos",
	"Matot":                     "Matos",
	"Menachot":                  "Menachos",
	"Midot":                     "Midos",
	"Mincha Gedolah":            "Minchah Gedolah",
	"Mincha Ketanah":            "Minchah Ketanah",
	"Parashat":                  "Parshas",
	"Pesach II (CH''M)":         "Pesach II (CH\"M)",
	"Pesach III (CH''M)":        "Pesach III (CH\"M)",
	"Pesach IV (CH''M)":         "Pesach IV (CH\"M)",
	"Pesach Sheni":              "Pesach Sheini",
	"Pesach V (CH''M)":          "Pesach V (CH\"M)",
	"Pesach VI (CH''M)":         "Pesach VI (CH\"M)",
	"Plag HaMincha":             "Plag HaMinchah",
	"Re'eh":                     "Re'ei",
	"Rosh Hashana":              "Rosh Hashanah",
	"Rosh Hashana I":            "Rosh Hashanah I",
	"Rosh Hashana II":           "Rosh Hashanah II",
	"Sh'lach":                   "Shelach",
	"Sh'vat":                    "Shvat",
	"Shabbat":                   "Shabbos",
	"Shabbat Chazon":            "Shabbos Chazon",
	"Shabbat HaChodesh":         "Shabbos HaChodesh",
	"Shabbat HaGadol":           "Shabbos HaGadol",
	"Shabbat Machar Chodesh":    "Shabbos Machar Chodesh",
	"Shabbat Mevarchim Chodesh": "Shabbos Mevarchim Chodesh",
	"Shabbat Nachamu":           "Shabbos Nachamu",
	"Shabbat Parah":             "Shabbos Parah",
	"Shabbat Rosh Chodesh":      "Shabbos Rosh Chodesh",
	"Shabbat Shekalim":          "Shabbos Shekalim",
	"Shabbat Shuva":             "Shabbos Shuvah",
	"Shabbat Zachor":            "Shabbos Zachor",
	"Shavuot":                   "Shavuos",
	"Shavuot I":                 "Shavuos I",
	"Shavuot II":                "Shavuos II",
	"Shemot":                    "Shemos",
	"Shevuot":                   "Shevuos",
	"Shmini":                    "Shemini",
	"Shmini Atzeret":            "Shemini Atzeres",
	"Simchat Torah":             "Simchas Torah",
	"Sukkot":                    "Sukkos",
	"Sukkot I":                  "Sukkos I",
	"Sukkot II":                 "Sukkos II",
	"Sukkot II (CH''M)":         "Sukkos II (CH\"M)",
	"Sukkot III (CH''M)":        "Sukkos III (CH\"M)",
	"Sukkot IV (CH''M)":         "Sukkos IV (CH\"M)",
	"Sukkot V (CH''M)":          "Sukkos V (CH\"M)",
	"Sukkot VI (CH''M)":         "Sukkos VI (CH\"M)",
	"Sukkot VII (Hoshana Raba)": "Sukkos VII (Hosha'ana Rabah)",
	"Ta'anit Bechorot":          "Ta'anis Bechoros",
	"Ta'anit Esther":            "Ta'anis Ester",
	"Taanit":                    "Ta'anis",
	"Tamuz":                     "Tammuz",
	"Tefilah, sof zeman":        "Sof Zman Tefilah",
	"Tevet":                     "Teives",
	"Tish'a B'Av":               "Tishah BeAv",
	"Tish'a B'Av (observed)":    "Tishah BeAv (observed)",
	"Toldot":                    "Toldos",
	"Tu B'Av":                   "Tu BeAv",
	"Tu B'Shvat":                "Tu BiShvat",
	"Tzom Gedaliah":             "Tzom Gedalyah",
	"Tzom Tammuz":               "Shivah Asar BeSammuz",
	"Vaera":                     "Vaeira",
	"Vaetchanan":                "Vaeschanan",
	"Vayechi":                   "Vaichi",
	"Vayera":                    "Vayeira",
	"Vayeshev":                  "Vayeishev",
	"Vayetzei":                  "Vayeitzei",
	"Vezot Haberakhah":          "Vezos Habrachah",
	"Yevamot":                   "Yevamos",
	"Yitro":                     "Yisro",
	"Yom HaAtzma'ut":            "Yom HaAtzmaut",
	"Yoma":                      "Yuma",
}

func Lookup_ashkenazi_standard(s string) (string, bool) {
	v, ok := dict_ashkenazi_standard[s]
	if ok {
		return v, true
	}
	return s, false
}
