/*
Hebcal's locales package supports string translations of holiday
names in multiple languages

  - en, sephardic: Sephardic transliterations (default if unspecified)
  - ashkenazi: Ashkenazic transliterations
  - he: Hebrew – עברית
  - de: German – Deutsch
  - es: Spanish – Español
  - fi: Finnish – Suomalainen
  - fr: French – français
  - hu: Hungarian – Magyar nyelv
  - pl: Polish – język polski
  - ro: Română – Romanian
  - ru: Russian – ру́сский язы́к
  - ashkenazi_litvish
  - ashkenazi_poylish
  - ashkenazi_romanian: Română (Ashk.) – Romanian (Ashk.)
  - ashkenazi_standard
*/
package locales
